@@ -1,23 +1,14 @@
 /*
- *
- * Copyright (C) 2003-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
-
+    SPDX-FileCopyrightText: 1998-2009 Sebastian Trueg <trueg@k3b.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef _K3B_PLUGIN_H_
 #define _K3B_PLUGIN_H_
 
 #include "k3b_export.h"
 #include <KPluginFactory>
+#include <KPluginMetaData>
 #include <KPluginInfo>
 #include <QObject>
 
@@ -41,7 +32,8 @@ namespace K3b {
         explicit Plugin( QObject* parent = 0 );
         ~Plugin() override;
 
-        KPluginInfo pluginInfo() const { return m_pluginInfo; }
+        KPluginInfo pluginInfo() const { return KPluginInfo::fromMetaData(d->metadata); }
+        KPluginMetaData pluginMetaData() const { return d->metadata; }
 
         /**
          * Version of the plugin system this plugin was written for.
@@ -56,7 +48,10 @@ namespace K3b {
         virtual QString categoryName() const = 0;
 
     private:
-        KPluginInfo m_pluginInfo;
+        struct Private {
+            KPluginMetaData metadata;
+        };
+        std::unique_ptr<Private> d=std::unique_ptr<Private>(new Private());
     };
 }
 
