@@ -1,17 +1,10 @@
 /*
- *
- * Copyright (C) 2003-2009 Sebastian Trueg <trueg@k3b.org>
- * Copyright (C) 2010 Michal Malek <michalm@jabster.pl>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 2003-2009 Sebastian Trueg <trueg@k3b.org>
+    SPDX-FileCopyrightText: 2010 Michal Malek <michalm@jabster.pl>
+    SPDX-FileCopyrightText: 1998-2009 Sebastian Trueg <trueg@k3b.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "k3bsoxencoder.h"
 #include "k3bsoxencoderdefaults.h"
@@ -33,7 +26,8 @@
 #include <sys/types.h>
 
 
-K3B_EXPORT_PLUGIN( k3bsoxencoder, K3bSoxEncoder )
+K_PLUGIN_CLASS_WITH_JSON(K3bSoxEncoder , "k3bsoxencoder.json")
+
 
 namespace {
 
